<?php
/*
Plugin Name: Redirects visitors (Site)
Plugin URI: http://www.easytoolswp.com
Description: Redirects visitors to a specified URL after a specified number of seconds
Version: 1.0
Author: EasyToolsWP
Author URI: http://www.easytoolswp.com
*/

// Add settings page to admin menu
add_action('admin_menu', 'redirector_add_admin_menu');
add_action('admin_init', 'redirector_settings_init');

function redirector_add_admin_menu() {
    add_options_page('Redirector Settings', 'Redirector Settings', 'manage_options', 'redirector_settings_page', 'redirector_settings_page');
}

function redirector_settings_init() {
    register_setting('redirector_plugin_settings_group', 'redirector_settings');

    add_settings_section(
        'redirector_plugin_settings_section',
        'Redirector Settings',
        'redirector_settings_section_callback',
        'redirector_plugin_settings_group'
    );

    add_settings_field(
        'redirector_enable',
        'Enable Redirection',
        'redirector_enable_callback',
        'redirector_plugin_settings_group',
        'redirector_plugin_settings_section'
    );

    add_settings_field(
        'redirector_seconds',
        'Number of Seconds',
        'redirector_seconds_callback',
        'redirector_plugin_settings_group',
        'redirector_plugin_settings_section'
    );

    add_settings_field(
        'redirector_url',
        'Redirect URL',
        'redirector_url_callback',
        'redirector_plugin_settings_group',
        'redirector_plugin_settings_section'
    );
}

function redirector_settings_section_callback() {
    echo '<p>Enter the number of seconds and the URL to redirect visitors.</p>';
}

function redirector_enable_callback() {
    $options = get_option('redirector_settings');
    $checked = isset($options['redirector_enable']) ? checked(1, $options['redirector_enable'], false) : '';
    echo '<input type="checkbox" id="redirector_enable" name="redirector_settings[redirector_enable]" value="1" ' . $checked . ' />';
}

function redirector_seconds_callback() {
    $options = get_option('redirector_settings');
    echo '<input type="number" min="1" id="redirector_seconds" name="redirector_settings[redirector_seconds]" value="' . $options['redirector_seconds'] . '" />';
}

function redirector_url_callback() {
    $options = get_option('redirector_settings');
    echo '<input type="url" id="redirector_url" name="redirector_settings[redirector_url]" value="' . $options['redirector_url'] . '" />';
}

function redirector_settings_page() {
    ?>
    <div class="wrap">
        <h2>Redirector Settings</h2>

        <form action="options.php" method="post">
            <?php
            settings_fields('redirector_plugin_settings_group');
            do_settings_sections('redirector_plugin_settings_group');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// Perform redirection
function redirector_redirect() {
    if (is_admin() || function_exists('elementor') || (defined('ELEMENTOR_VERSION') && \Elementor\Plugin::$instance->editor->is_edit_mode())) {
        return;
    }

    $options = get_option('redirector_settings');
    $redirect_enable = isset($options['redirector_enable']) ? $options['redirector_enable'] : false;
    $redirect_url = $options['redirector_url'];
    $redirect_seconds = $options['redirector_seconds'];

    if ($redirect_enable && !empty($redirect_url) && $redirect_seconds > 0) {
        echo "<script>
            setTimeout(function() {
                window.location.href = '$redirect_url';
            }, $redirect_seconds * 1000);
        </script>";
    }
}

add_action('wp_footer', 'redirector_redirect');
